@@ -25,7 +25,14 @@ class ProductTableRow(ModelForm):
 class PageForm(ModelForm):
     class Meta:
         model = Page
-        exclude = ('identifier', 'url', 'template_override',)
+        fields = (
+            'title',
+            'status',
+            'slug',
+            'body',
+            'parent',
+            'header_image',
+        )
         widgets = {
             'body': TinyMCE(attrs={'cols': 80, 'rows': 30})
         }
@@ -34,4 +41,12 @@ class PageForm(ModelForm):
 class CategoryForm(ModelForm):
     class Meta:
         model = Category
+        fields = (
+            'name',
+            'sort_index',
+            'slug',
+            'is_special',
+            'introduction_text',
+            'image'
+        )
         #exclude = ('identifier', 'url', 'template_override',)
