@@ -60,30 +60,26 @@ def categories(request):
 @user_passes_test(lambda u: u.is_staff)
 def category(request, category=None):
     if request.method == 'POST':
-        data = request.POST
+        data = (request.POST, request.FILES)
     else:
-        data = None
-
+        data = (None,)
     if category:
         category = get_object_or_404(Category, id=category)
-        form = CategoryForm(data, instance=category)
+        form = CategoryForm(*data, instance=category)
     else:
-        form = CategoryForm(data)
+        form = CategoryForm(*data)
 
     if form.is_valid():
-        if category:
-            form.save()
-        else:
-            category = form.save(commit=False)
-            if not category.slug:
-                category.slug = slugify(category.name)
+        category = form.save(commit=False)
+        if not category.slug:
+            category.slug = slugify(category.name)
 
-            category.save()
-            return HttpResponseRedirect(
-                reverse('luxuryadmin:category', kwargs={
-                    'category': category.id
-                })
-            )
+        category.save()
+        return HttpResponseRedirect(
+            reverse('luxuryadmin:category', kwargs={
+                'category': category.id
+            })
+        )
 
     return TemplateResponse(request, 'luxuryadmin/category.html', dict(
         form=form,
@@ -137,30 +133,25 @@ def pages(request):
 @user_passes_test(lambda u: u.is_staff)
 def page(request, page=None):
     if request.method == 'POST':
-        data = request.POST
+        data = (request.POST, request.FILES)
     else:
-        data = None
-
+        data = (None,)
     if page:
         page = get_object_or_404(Page, id=page)
-        form = PageForm(data, instance=page)
+        form = PageForm(*data, instance=page)
     else:
-        form = PageForm(data)
-
+        form = PageForm(*data)
     if form.is_valid():
-        if page:
-            form.save()
-        else:
-            page = form.save(commit=False)
-            if not page.slug:
-                page.slug = slugify(page.name)
-
-            page.save()
-            return HttpResponseRedirect(
-                reverse('luxuryadmin:page', kwargs={
-                    'page': page.id
-                })
-            )
+        page = form.save(commit=False)
+        if not page.slug:
+            page.slug = slugify(page.name)
+        page.save()
+        
+        return HttpResponseRedirect(
+            reverse('luxuryadmin:page', kwargs={
+                'page': page.id
+            })
+        )
 
     return TemplateResponse(request, 'luxuryadmin/page.html', dict(
         form=form,
